package org.tipple.mapDisplay;

import java.io.File;
import java.io.FileOutputStream;
import java.io.ObjectOutputStream;

import android.app.Activity;
import android.content.ContentResolver;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.util.Log;

public class TakePicture extends Activity {
	protected Uri imageUri;
	String filename = "imageExample.jpg";
	File photo;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		// retrieve value from picture taking
		Bundle extras = getIntent().getExtras();
		if (extras != null) {
			filename = extras.getString("filename");
		}
		startCameraActivity(filename);

	}

	protected void startCameraActivity(String filename) {

		Intent intent = new Intent("android.media.action.IMAGE_CAPTURE");
		photo = new File(Environment.getExternalStorageDirectory(), filename);
		intent.putExtra(MediaStore.EXTRA_OUTPUT, Uri.fromFile(photo));
		imageUri = Uri.fromFile(photo);
		startActivityForResult(intent, 0);

	}

	public void onActivityResult(int requestCode, int resultCode, Intent data) {

		super.onActivityResult(requestCode, resultCode, data);
		Log.i("TakePicture", "resultCode: " + resultCode);
		switch (resultCode) {
		case 0:
			Log.i("TakePicture", "User cancelled");
			break;

		case -1:
			onPhotoTaken();
			break;
		}
		this.finish(); // when user click on V then back to previous activity

	}

	private void onPhotoTaken() {
		Uri selectedImage = imageUri;
		getContentResolver().notifyChange(selectedImage, null);
		ContentResolver cr = getContentResolver();

		try {
			Bitmap bitmap = android.provider.MediaStore.Images.Media.getBitmap(
					cr, selectedImage);
			Log.i("TakePicture", "save file to the location" + filename);
			savePicture(tippleActivity.imageDirectory + filename, bitmap,
					getApplicationContext());
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	private void savePicture(String filename, Bitmap b, Context ctx) {
		if (!photo.exists()) {// look for sdcard directory
			try {
				ObjectOutputStream oos;
				FileOutputStream out = new FileOutputStream(filename);
				out = ctx.openFileOutput(filename, Context.MODE_PRIVATE);
				oos = new ObjectOutputStream(out);
				b.compress(Bitmap.CompressFormat.PNG, 100, oos);
				oos.close();
				oos.notifyAll();
				out.notifyAll();
				out.close();
			} catch (Exception e) {
				e.printStackTrace();
			}
		} else {
			Log.i("TakePicture", "file exist" + filename);
			return;
		}
	}

}
